@@ -13,7 +13,7 @@ from sentry_sdk.tracing import Transaction
 # Package information
 # ===================
 
-__version__ = "1.1.2"
+__version__ = "1.1.3"
 __project__ = "muffin-sentry"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -51,7 +51,7 @@ class Plugin(BasePlugin):
         # Setup Sentry
         sentry_init(dsn=self.cfg.dsn, **self.cfg.sdk_options)
 
-    async def middleware(self, handler: ASGIApp, request: Request, receive: Receive, send: Send):
+    async def middleware(self, handler: ASGIApp, request: Request, receive: Receive, send: Send):  # type: ignore
         """Capture exceptions to Sentry."""
         hub = Hub(Hub.current)
         with hub.configure_scope() as scope:
